.. _tutorials-crab_mwl_sed:

Crab multi-wavelength SED
=========================

Here we load Crab pulsar and nebula flux points `gammapy.datasets.load_crab_flux_points`

TODO:

* describe data and emission components
* perform fit with gammafit!

.. plot:: tutorials/crab_mwl_sed/crab_mwl_sed.py
   :include-source:
   